These functions return a list of Boolean variables whose value depends
on whether or not m has the property in question.
If argument give.answers takes the default value of
FALSE, a Boolean value is returned that shows whether the
sufficient conditions are met.
If argument give.answers is TRUE, a detailed list is
given that shows the status of each individual test, both for the
necessary and sufficient conditions. The value of the second element
(named necessary) is the status of their Theorem 1 on page 154.
Note that the necessary conditions do not depend on the base b
(technically, neither do the sufficient conditions, for being a square
palindrome requires the sums to match for every base b.
In this implementation, “sufficient” is defined only with
respect to a particular base).